@@ -3,8 +3,8 @@
 
 #include "ggit-enum-types.h"
 
-/* enumerations from "ggit-types.h" */
-#include "ggit-types.h"
+/* enumerations from "./ggit-types.h" */
+#include "./ggit-types.h"
 
 GType
 ggit_branch_type_get_type (void)
@@ -411,9 +411,9 @@ ggit_file_mode_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
-			{ GGIT_FILE_MODE_NEW,
-			  "GGIT_FILE_MODE_NEW",
-			  "new" },
+			{ GGIT_FILE_MODE_UNREADABLE,
+			  "GGIT_FILE_MODE_UNREADABLE",
+			  "unreadable" },
 			{ GGIT_FILE_MODE_TREE,
 			  "GGIT_FILE_MODE_TREE",
 			  "tree" },
@@ -892,9 +892,6 @@ ggit_status_option_get_type (void)
 			{ GGIT_STATUS_OPTION_DEFAULT,
 			  "GGIT_STATUS_OPTION_DEFAULT",
 			  "default" },
-			{ GGIT_STATUS_OPTION_RECURSE_UNTRACKED_DIRS,
-			  "GGIT_STATUS_OPTION_RECURSE_UNTRACKED_DIRS",
-			  "recurse-untracked-dirs" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_flags_register_static (
@@ -1179,6 +1176,61 @@ ggit_diff_format_email_flags_get_type (void)
 	return the_type;
 }
 
+GType
+ggit_credtype_get_type (void)
+{
+	static GType the_type = 0;
+	
+	if (the_type == 0)
+	{
+		static const GFlagsValue values[] = {
+			{ GGIT_CREDTYPE_USERPASS_PLAINTEXT,
+			  "GGIT_CREDTYPE_USERPASS_PLAINTEXT",
+			  "userpass-plaintext" },
+			{ GGIT_CREDTYPE_SSH_KEY,
+			  "GGIT_CREDTYPE_SSH_KEY",
+			  "ssh-key" },
+			{ GGIT_CREDTYPE_SSH_CUSTOM,
+			  "GGIT_CREDTYPE_SSH_CUSTOM",
+			  "ssh-custom" },
+			{ GGIT_CREDTYPE_DEFAULT,
+			  "GGIT_CREDTYPE_DEFAULT",
+			  "default" },
+			{ GGIT_CREDTYPE_SSH_INTERACTIVE,
+			  "GGIT_CREDTYPE_SSH_INTERACTIVE",
+			  "ssh-interactive" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_flags_register_static (
+				g_intern_static_string ("GgitCredtype"),
+				values);
+	}
+	return the_type;
+}
+
+GType
+ggit_direction_get_type (void)
+{
+	static GType the_type = 0;
+	
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ GGIT_DIRECTION_FETCH,
+			  "GGIT_DIRECTION_FETCH",
+			  "fetch" },
+			{ GGIT_DIRECTION_PUSH,
+			  "GGIT_DIRECTION_PUSH",
+			  "push" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("GgitDirection"),
+				values);
+	}
+	return the_type;
+}
+
 
 /* Generated data ends here */
 
